#ifdef FUNCTION
#undef FUNCTION
#endif

#ifdef CONCAT3
#undef CONCAT3
#endif

#ifdef CONCAT3x
#undef CONCAT3x
#endif

#ifdef CONCAT2
#undef CONCAT2
#endif

#ifdef CONCAT2x
#undef CONCAT2x
#endif

#ifdef TYPE
#undef TYPE
#endif

#ifdef TYPE2
#undef TYPE2
#endif

#ifdef USES_LONGDOUBLE
#undef USES_LONGDOUBLE
#endif

#undef BASE
#undef BASE_EPSILON
#undef SHORT
#undef ATOMIC
#undef MULTIPLICITY
#undef IN_FORMAT
#undef OUT_FORMAT
#undef ATOMIC_IO
#undef ZERO
#undef ONE
#undef NAME
#undef STRING
#undef EXPAND
